@@ -168,6 +168,7 @@ def get_page_links(domain_url, url, allowed_domains, file_size=1024, sleep_time=
                     else:
                         link_text = ""
 
+                    raw_href = ''
                     try:
                         raw_href = tag[verb]
                     except:
@@ -177,7 +178,9 @@ def get_page_links(domain_url, url, allowed_domains, file_size=1024, sleep_time=
                     match = check_match(domain_url, raw_href, allowed_domains)
                     abs_link = urljoin(domain_url, raw_href)
                     links.append((match,abs_link,link_text))
-        
+       
+                    log( 'get_page_links(): raw_href={0}, match={1}, abs_link={2}, links.length={3}'.format( raw_href, match, abs_link, len(links)) )
+ 
                     abs_links = sanity_check_url(domain_url, raw_href)
                     for l in abs_links:
                         links.append((match,l,link_text))
